# ----------------------------------------------------------------------------------------------------
# IBM Confidential
# Licensed Materials - Property of IBM
# 5737-H76, 5900-A3Q
# © Copyright IBM Corp. 2025  All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by
# GSA ADPSchedule Contract with IBM Corp.
# ----------------------------------------------------------------------------------------------------

# --- Prompt Templates ---
full_response_eval_system_prompt = """You are an impartial judge evaluating the quality of an AI model's response. You will receive:

Input: The text the model was asked to process or respond to.
Output: The model's response text.
Your task is to score the model's response on a scale of 0 to 1, considering the following criteria.
You may also consider other relevant factors that contribute to the overall quality of the response.

Evaluation Criteria:
{evaluation_criteria}

Provide a score from 0 to 1 and explain your reasoning clearly and concisely. End the response with 'Final Score: <score>' (e.g., 'Final Score: 0.7').
"""

full_response_eval_human_prompt = """The response to analyze:
Input: '{model_input}'
Output: '{model_output}'

--- Begin Evaluation ---
Textual Evaluation: [Your textual evaluation here]
Evaluation score: [Your score here]
"""

summarization_system_prompt = """
You are given an evaluation text produced by a judge model. Summarize the text in a few sentences.
Focus on the core reasoning for the score and the final score itself.
Remove redundancies and make it concise while keeping the essential information.
Disregard the score given by the model and focus on the textual feedback. 
"""

summarization_human_prompt = """
Evaluation Text to Summarize:
{evaluation_text}
"""

map_shortcomings_system_prompt = """You are an expert analyst reviewing evaluation feedback for AI model responses.
Your task is to determine which of the following common shortcomings are mentioned or implied in the evaluation text.
The shortcoming must be included with negative sentiment. For instance, if the shortcoming is
"The answer lacks factual accuracy" and the evaluation text mentions "The answer is factually accurate", than the shortcoming is NOT mentioned in the evaluation text.

Analyze the evaluation text and determine which shortcomings are present.
For each shortcoming, respond with a 1 if it is mentioned or implied, or 0 if it is not mentioned.
Your response should be a Python list of {num_shortcomings} binary values (0 or 1).
For example: [1,0,0,1,0,0,0] would mean shortcomings 1 and 4 are present, and the others are not.
Respond ONLY with the list in the format [0,1,0,...] with no additional text.
"""

map_shortcomings_human_prompt = """
The shortcomings list to analyze:
{shortcomings_list}

Evaluation text to analyze:
{eval_text}\n

Which shortcomings (1-{num_shortcomings}) are mentioned or implied in this evaluation? Respond with a Python list of {num_shortcomings} binary values (0 or 1) in the format [0,1,0,...]."
"""

recurrent_issues_synthesis_system_prompt ="""You are an expert analyst tasked with identifying common themes in evaluation feedback for an AI model's answers. Below is a collection of evaluation texts assessing the quality of different answers.
Your goal is to identify the most significant and frequent types of shortcomings or negative feedback mentioned in these evaluations. Please provide a list of concise phrases describing these common issues. Focus on actionable feedback points that could help improve the model's responses.

Guidelines for identifying shortcomings:
1. Look for patterns across multiple evaluations
2. Focus on specific, actionable issues rather than general complaints
3. Consider both content-related issues (accuracy, completeness) and presentation issues (clarity, structure)
4. Prioritize issues that appear frequently or have significant impact
5. Be specific but concise in your descriptions
6. Ensure the issues are distinct and not overlapping. 

Do NOT list positive feedback. Focus only on areas for improvement or reasons for lower scores.
Present the output ONLY as a Python list of strings. Your response MUST start with '[' and end with ']'.
"""

recurrent_issues_synthesis_human_prompt = """--- Begin Evaluation Texts ---
{concatenated_evaluation_text}
--- End Evaluation Texts ---

Synthesized List of Common Shortcomings (Python List format ONLY):
"""

shortcomings_clustering_system_prompt = """You are given a list of short action items that describe recurring issues found in responses generated by a language model. These items may contain duplicates or very similar entries phrased differently.
Your task is to analyze the list, remove duplicates and consolidate redundant items into a smaller set of distinct, clearly described issues.
Instructions:
- Group nearly identical feedback items that refer to the same concerns.
- If there are two issues assessing different aspects of the same topic - do not merge them.  
- Do not merge issues with the same topic but opposite concerns (e.g: overly verbose / not verbose enough).
- For each group, write a single and clear issue that captures the common idea.
- Ensure that each issue addresses only a single concern or aspect. Do not merge distinct issues with related topics.
- Ensure that the final list avoids redundancy and represents the full variety of distinct concerns from the original list.
- Ensure no important information is lost from the original list — all key concerns must be preserved.
- Explain your reasoning for each consolidation decision (e.g., which items were grouped together and why).
- Finish your response by outputting 'Final list:' and then a properly formatted Python list of strings (with each element in double quotes) containing the consolidated issues.
"""

shortcomings_clustering_human_prompt = """Now process the following list:
{recurring_issues_list}
"""

